==> vtk6-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkAbstractInterpolatedVelocityField.java <==
// java wrapper for vtkAbstractInterpolatedVelocityField object
//

package vtk;
import vtk.*;

public class vtkAbstractInterpolatedVelocityField extends vtkFunctionSet
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetCaching_2(boolean id0);
  public void SetCaching(boolean id0)
    { SetCaching_2(id0); }

  private native boolean GetCaching_3();
  public boolean GetCaching()
    { return GetCaching_3(); }

  private native int GetCacheHit_4();
  public int GetCacheHit()
    { return GetCacheHit_4(); }

  private native int GetCacheMiss_5();
  public int GetCacheMiss()
    { return GetCacheMiss_5(); }

  private native long GetLastDataSet_6();
  public vtkDataSet GetLastDataSet() {
    long temp = GetLastDataSet_6();

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native int GetLastCellId_7();
  public int GetLastCellId()
    { return GetLastCellId_7(); }

  private native void SetLastCellId_8(int id0);
  public void SetLastCellId(int id0)
    { SetLastCellId_8(id0); }

  private native void SetLastCellId_9(int id0,int id1);
  public void SetLastCellId(int id0,int id1)
    { SetLastCellId_9(id0,id1); }

  private native String GetVectorsSelection_10();
  public String GetVectorsSelection()
    { return GetVectorsSelection_10(); }

  private native int GetVectorsType_11();
  public int GetVectorsType()
    { return GetVectorsType_11(); }

  private native void SelectVectors_12(int id0,String id1);
  public void SelectVectors(int id0,String id1)
    { SelectVectors_12(id0,id1); }

  private native void SetNormalizeVector_13(boolean id0);
  public void SetNormalizeVector(boolean id0)
    { SetNormalizeVector_13(id0); }

  private native boolean GetNormalizeVector_14();
  public boolean GetNormalizeVector()
    { return GetNormalizeVector_14(); }

  private native void SetForceSurfaceTangentVector_15(boolean id0);
  public void SetForceSurfaceTangentVector(boolean id0)
    { SetForceSurfaceTangentVector_15(id0); }

  private native boolean GetForceSurfaceTangentVector_16();
  public boolean GetForceSurfaceTangentVector()
    { return GetForceSurfaceTangentVector_16(); }

  private native void SetSurfaceDataset_17(boolean id0);
  public void SetSurfaceDataset(boolean id0)
    { SetSurfaceDataset_17(id0); }

  private native boolean GetSurfaceDataset_18();
  public boolean GetSurfaceDataset()
    { return GetSurfaceDataset_18(); }

  private native void CopyParameters_19(vtkAbstractInterpolatedVelocityField id0);
  public void CopyParameters(vtkAbstractInterpolatedVelocityField id0)
    { CopyParameters_19(id0); }

  private native void ClearLastCellId_20();
  public void ClearLastCellId()
    { ClearLastCellId_20(); }

  private native int GetLastLocalCoordinates_21(double id0[]);
  public int GetLastLocalCoordinates(double id0[])
    { return GetLastLocalCoordinates_21(id0); }

  public vtkAbstractInterpolatedVelocityField() { super(); }

  public vtkAbstractInterpolatedVelocityField(long id) { super(id); }

}

==> vtk-8.2.0-20-armv6h.pkg.tar.xz: vtk/vtkAbstractInterpolatedVelocityField.java <==
// java wrapper for vtkAbstractInterpolatedVelocityField object
//

package vtk;
import vtk.*;

public class vtkAbstractInterpolatedVelocityField extends vtkFunctionSet
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetCaching_2(boolean id0);
  public void SetCaching(boolean id0)
    { SetCaching_2(id0); }

  private native boolean GetCaching_3();
  public boolean GetCaching()
    { return GetCaching_3(); }

  private native int GetCacheHit_4();
  public int GetCacheHit()
    { return GetCacheHit_4(); }

  private native int GetCacheMiss_5();
  public int GetCacheMiss()
    { return GetCacheMiss_5(); }

  private native long GetLastDataSet_6();
  public vtkDataSet GetLastDataSet() {
    long temp = GetLastDataSet_6();

    if (temp == 0) return null;
    return (vtkDataSet)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native int GetLastCellId_7();
  public int GetLastCellId()
    { return GetLastCellId_7(); }

  private native void SetLastCellId_8(int id0);
  public void SetLastCellId(int id0)
    { SetLastCellId_8(id0); }

  private native void SetLastCellId_9(int id0,int id1);
  public void SetLastCellId(int id0,int id1)
    { SetLastCellId_9(id0,id1); }

  private native String GetVectorsSelection_10();
  public String GetVectorsSelection()
    { return GetVectorsSelection_10(); }

  private native int GetVectorsType_11();
  public int GetVectorsType()
    { return GetVectorsType_11(); }

  private native void SelectVectors_12(int id0,String id1);
  public void SelectVectors(int id0,String id1)
    { SelectVectors_12(id0,id1); }

  private native void SetNormalizeVector_13(boolean id0);
  public void SetNormalizeVector(boolean id0)
    { SetNormalizeVector_13(id0); }

  private native boolean GetNormalizeVector_14();
  public boolean GetNormalizeVector()
    { return GetNormalizeVector_14(); }

  private native void SetForceSurfaceTangentVector_15(boolean id0);
  public void SetForceSurfaceTangentVector(boolean id0)
    { SetForceSurfaceTangentVector_15(id0); }

  private native boolean GetForceSurfaceTangentVector_16();
  public boolean GetForceSurfaceTangentVector()
    { return GetForceSurfaceTangentVector_16(); }

  private native void SetSurfaceDataset_17(boolean id0);
  public void SetSurfaceDataset(boolean id0)
    { SetSurfaceDataset_17(id0); }

  private native boolean GetSurfaceDataset_18();
  public boolean GetSurfaceDataset()
    { return GetSurfaceDataset_18(); }

  private native void CopyParameters_19(vtkAbstractInterpolatedVelocityField id0);
  public void CopyParameters(vtkAbstractInterpolatedVelocityField id0)
    { CopyParameters_19(id0); }

  private native void ClearLastCellId_20();
  public void ClearLastCellId()
    { ClearLastCellId_20(); }

  private native int GetLastLocalCoordinates_21(double id0[]);
  public int GetLastLocalCoordinates(double id0[])
    { return GetLastLocalCoordinates_21(id0); }

  public vtkAbstractInterpolatedVelocityField() { super(); }

  public vtkAbstractInterpolatedVelocityField(long id) { super(id); }

}
